@@ -4,12 +4,14 @@ dicom2nifti
 
 @author: abrys
 """
+import copy
 import logging
 import os
 import struct
 
 import numpy
 import pydicom
+from pydicom import dcmread
 from pydicom.tag import Tag
 
 import dicom2nifti.settings
@@ -35,7 +37,7 @@ def read_dicom_directory(dicom_directory, stop_before_pixels=False):
         for dicom_file in files:
             file_path = os.path.join(root, dicom_file)
             if is_dicom_file(file_path):
-                dicom_headers = pydicom.read_file(file_path,
+                dicom_headers = dcmread(file_path,
                                                   defer_size="1 KB",
                                                   stop_before_pixels=stop_before_pixels,
                                                   force=dicom2nifti.settings.pydicom_read_force)
@@ -303,27 +305,31 @@ def get_volume_pixeldata(sorted_slices):
     :type sorted_slices: list of slices
     :param sorted_slices: sliced sored in the correct order to create volume
     """
-    slices = []
     combined_dtype = None
-    for slice_ in sorted_slices:
-        slice_data = _get_slice_pixeldata(slice_)
-        slice_data = slice_data[numpy.newaxis, :, :]
-        slices.append(slice_data)
+    volume = None
+    for i, slice_ in enumerate(sorted_slices):
+        # create copy so we don't load all pixel data on the original slice that is kept in memory
+        slice_copy = copy.deepcopy(slice_)
+        slice_data = _get_slice_pixeldata(slice_copy)
+        del slice_copy
         if combined_dtype is None:
             combined_dtype = slice_data.dtype
         else:
             combined_dtype = numpy.promote_types(combined_dtype, slice_data.dtype)
-
-    # create the new volume with with the correct data
-    vol = numpy.concatenate(slices, axis=0)
+        if volume is None:
+            volume = numpy.zeros((len(sorted_slices), ) + slice_data.shape,
+                                 combined_dtype)
+        if volume.dtype != combined_dtype:
+            volume = volume.astype(combined_dtype)
+        volume[i] = slice_data
 
     # Done
     # if rgb data do separate transpose
-    if len(vol.shape) == 4 and vol.shape[3] == 3:
-        vol = numpy.transpose(vol, (2, 1, 0, 3))
+    if len(volume.shape) == 4 and volume.shape[3] == 3:
+        volume = numpy.transpose(volume, (2, 1, 0, 3))
     else:
-        vol = numpy.transpose(vol, (2, 1, 0))
-    return vol
+        volume = numpy.transpose(volume, (2, 1, 0))
+    return volume
 
 
 def _get_slice_pixeldata(dicom_slice):
@@ -539,7 +545,7 @@ def do_scaling(data, rescale_slope, rescale_intercept, private_scale_slope=1.0,
         # Determine required datatype from that
         if minimum_required < 0:
             # Signed integer type
-            maximum_required = max([-minimum_required, maximum_required])
+            maximum_required = max([-(minimum_required + 1), maximum_required])
             if maximum_required < 2 ** 7:
                 dtype = numpy.int8
             elif maximum_required < 2 ** 15:
@@ -1105,6 +1111,23 @@ def set_tr_te(nifti_image, repetition_time, echo_time):
     :param repetition_time: repetition time
     :param nifti_image: nifti image to set the info to
     """
+
+    def is_float(number):
+        """
+        Helper to check if something is a float
+        """
+        try:
+            float(number)
+            return True
+        except ValueError:
+            return False
+
+    # only set if it is an actual float, can also be empty/none
+    if not is_float(repetition_time) or not is_float(echo_time):
+        return
+    repetition_time = float(repetition_time)
+    echo_time = float(echo_time)
+
     # set the repetition time in pixdim
     nifti_image.header.structarr['pixdim'][4] = repetition_time / 1000.0
 
@@ -1139,7 +1162,7 @@ def is_dicom_file(filename):
         return True
     if dicom2nifti.settings.pydicom_read_force:
         try:
-            dicom_headers = pydicom.read_file(filename, defer_size="1 KB", stop_before_pixels=True, force=True)
+            dicom_headers = dcmread(filename, defer_size="1 KB", stop_before_pixels=True, force=True)
             if dicom_headers is not None:
                 return True
         except:
