@@ -4,12 +4,14 @@ dicom2nifti
 
 @author: abrys
 """
+import gc
 import logging
 import os
 import shutil
 import tempfile
 
-from nibabel.pydicom_compat import pydicom
+import pydicom
+from pydicom import dcmread
 from pydicom.tag import Tag
 
 import dicom2nifti.common as common
@@ -128,6 +130,7 @@ def dicom_array_to_nifti(dicom_list, output_file, reorient_nifti=True):
 
     # do image reorientation if needed
     if reorient_nifti or settings.resample:
+        gc.collect()
         results['NII'] = image_reorientation.reorient_image(results['NII'], results['NII_FILE'])
 
     # resampling needs to be after reorientation
@@ -197,7 +200,7 @@ def _get_first_header(dicom_directory):
             if not common.is_dicom_file(file_path):
                 continue
             # read the headers
-            return pydicom.read_file(file_path,
+            return dcmread(file_path,
                                      stop_before_pixels=True,
                                      force=dicom2nifti.settings.pydicom_read_force)
     # no dicom files found
